summaryrefslogtreecommitdiff
path: root/zephyr/projects/corsola/BUILD.py
diff options
context:
space:
mode:
Diffstat (limited to 'zephyr/projects/corsola/BUILD.py')
-rw-r--r--zephyr/projects/corsola/BUILD.py63
1 files changed, 54 insertions, 9 deletions
diff --git a/zephyr/projects/corsola/BUILD.py b/zephyr/projects/corsola/BUILD.py
index 83ad865cb1..32ccd9ebf1 100644
--- a/zephyr/projects/corsola/BUILD.py
+++ b/zephyr/projects/corsola/BUILD.py
@@ -1,15 +1,15 @@
-# Copyright 2021 The Chromium OS Authors. All rights reserved.
+# Copyright 2021 The ChromiumOS Authors
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
"""Define zmake projects for corsola."""
# Default chip is it8xxx2, some variants will use NPCX9X.
def register_corsola_project(
project_name,
- chip="it8xxx2",
+ chip="it81202bx",
extra_dts_overlays=(),
extra_kconfig_files=(),
):
@@ -39,12 +39,14 @@ register_corsola_project(
here / "gpio_krabby.dts",
here / "i2c_krabby.dts",
here / "interrupts_krabby.dts",
- here / "cbi_eeprom.dts",
here / "led_krabby.dts",
here / "motionsense_krabby.dts",
here / "usbc_krabby.dts",
],
- extra_kconfig_files=[here / "prj_krabby.conf"],
+ extra_kconfig_files=[
+ here / "prj_it81202_base.conf",
+ here / "prj_krabby.conf",
+ ],
)
register_corsola_project(
@@ -56,7 +58,6 @@ register_corsola_project(
here / "host_interface_npcx.dts",
here / "i2c_kingler.dts",
here / "interrupts_kingler.dts",
- here / "cbi_eeprom.dts",
here / "gpio_kingler.dts",
here / "npcx_keyboard.dts",
here / "led_kingler.dts",
@@ -64,7 +65,10 @@ register_corsola_project(
here / "usbc_kingler.dts",
here / "default_gpio_pinctrl_kingler.dts",
],
- extra_kconfig_files=[here / "prj_kingler.conf"],
+ extra_kconfig_files=[
+ here / "prj_npcx993_base.conf",
+ here / "prj_kingler.conf",
+ ],
)
register_corsola_project(
@@ -76,9 +80,10 @@ register_corsola_project(
here / "host_interface_npcx.dts",
here / "i2c_kingler.dts",
here / "interrupts_kingler.dts",
- here / "cbi_eeprom.dts",
+ here / "cbi_steelix.dts",
here / "gpio_steelix.dts",
here / "npcx_keyboard.dts",
+ here / "keyboard_steelix.dts",
here / "led_steelix.dts",
here / "motionsense_kingler.dts",
here / "motionsense_steelix.dts",
@@ -87,7 +92,47 @@ register_corsola_project(
here / "default_gpio_pinctrl_kingler.dts",
],
extra_kconfig_files=[
- here / "prj_kingler.conf",
+ here / "prj_npcx993_base.conf",
here / "prj_steelix.conf",
],
)
+
+
+register_corsola_project(
+ "tentacruel",
+ extra_dts_overlays=[
+ here / "adc_tentacruel.dts",
+ here / "battery_tentacruel.dts",
+ here / "cbi_tentacruel.dts",
+ here / "gpio_tentacruel.dts",
+ here / "i2c_tentacruel.dts",
+ here / "interrupts_tentacruel.dts",
+ here / "led_tentacruel.dts",
+ here / "motionsense_tentacruel.dts",
+ here / "usbc_tentacruel.dts",
+ here / "thermistor_tentacruel.dts",
+ ],
+ extra_kconfig_files=[
+ here / "prj_it81202_base.conf",
+ here / "prj_tentacruel.conf",
+ ],
+)
+
+register_corsola_project(
+ "magikarp",
+ extra_dts_overlays=[
+ here / "adc_magikarp.dts",
+ here / "battery_magikarp.dts",
+ here / "cbi_magikarp.dts",
+ here / "gpio_magikarp.dts",
+ here / "i2c_magikarp.dts",
+ here / "interrupts_magikarp.dts",
+ here / "led_magikarp.dts",
+ here / "motionsense_magikarp.dts",
+ here / "usbc_magikarp.dts",
+ ],
+ extra_kconfig_files=[
+ here / "prj_it81202_base.conf",
+ here / "prj_magikarp.conf",
+ ],
+)
@@ -1,15 +1,15 @@
# found in the LICENSE file.
"""Define zmake projects for corsola."""
-# Default chip is it8xxx2, some variants will use NPCX9X.
+# Default chip is it81202bx, some variants will use NPCX9X.
def register_corsola_project(
project_name,